# the statusbar

was loosely inspired by irssi and looks something like this:

`192939   1: #g(5)  +9   h:2   a:2,3   ed, ned, ame, same, sam`

* according to the server, the UTC time is `19:29:39`

* you are in window `1` (the first channel you joined), which is channel `#g`, which has `5` users

* there is `9` more messages to see if you scroll down

* `h:2` you were hilighted (your name was mentioned) in window `2`; use the command **`/2`** or just press **`CTRL-E`** which takes you to the channel with the most important happening

* `a:2,3` activity in windows `2` and `3` which you haven't seen

* the 5 users in `#g`, sorted by when they last said soemthing
